diff level2/modules/kernel/fsrqmem.asm @ 2118:7fca19b7c923

ChangeLog udpated FSRqMem optimization added
author boisy
date Fri, 24 Aug 2007 03:30:33 +0000
parents 5ecf6e023a64
children 055c774cb633
line wrap: on
line diff
--- a/level2/modules/kernel/fsrqmem.asm	Fri Aug 24 03:25:48 2007 +0000
+++ b/level2/modules/kernel/fsrqmem.asm	Fri Aug 24 03:30:33 2007 +0000
@@ -62,14 +62,14 @@
          cmpb  #DAT.BlCt    Done whole 64k system space?
          blo   L082F        no, keep checking
 * Now we can actually attempt to allocate the system RAM requested
 * NOTE: Opt for Coco/TC9 OS9 ONLY: skip last 17 pages with leay -17,y since
 * they are: Kernel (REL/BOOT/OS9P1 - 15 pages), vector RAM & I/O (2 pages)
 * (Already permanently marked @ L01D2)
 * At the start, Y is pointing to the end of the SMAP table+1
          ldx   <D.SysMem    Get start of table ptr
          ldb   #32          skip block 0: it's always full
          abx                same size, but faster than leax $20,x
-         leay  -17,y        Skip Kernel, Vector RAM & I/O (Can't be free)
+         leay  -19,y        Skip Kernel, Vector RAM & I/O (Can't be free)
 L0857    ldb   R$A,u        Get # 256 byte pages requested
 * Loop (from end of system mem map) to look for # continuous pages requested
 L0859    equ   *
@@ -62,14 +62,14 @@
          blo   L082F        no, keep checking
 * Now we can actually attempt to allocate the system RAM requested
-* NOTE: Opt for Coco/TC9 OS9 ONLY: skip last 17 pages with leay -17,y since
-* they are: Kernel (REL/BOOT/OS9P1 - 15 pages), vector RAM & I/O (2 pages)
+* NOTE: Opt for CoCo/TC9 OS9 ONLY: skip last 19 pages since
+* they are: Kernel (REL/BOOT/KRN - 17 pages), vector RAM & I/O (2 pages)
 * (Already permanently marked @ L01D2)
 * At the start, Y is pointing to the end of the SMAP table+1